@@ -3,7 +3,7 @@ from scipy.stats import trim_mean
 import pandas as pd
 import numpy as np
 from numpy.random import random
-random_float = random.RandomState(69)
+random_float = np.random.RandomState(69)
 
 class PD_input:
     '''Class containing functions to analyze the default peptide/PSM output from ProteomeDiscoverer. All column names are assumed
